@@ -1,9 +1,11 @@
 require 'spec_helper'
+
 require 'active_record'
 require 'fast_gettext/translation_repository/db'
-
 FastGettext::TranslationRepository::Db.require_models
 
+SingleCov.covered! uncovered: 3
+
 describe FastGettext::TranslationRepository::Db do
   before :all do
     ActiveRecord::Base.establish_connection(
@@ -69,6 +71,10 @@ describe FastGettext::TranslationRepository::Db do
     @rep.plural('Axis','Axis').should == ['Achse','Achsen']
   end
 
+  it "can reload" do
+    @rep.reload.should == true
+  end
+
   it "can ignore newline format" do
     create_translation "good\r\nmorning", "guten\r\nMorgen"
     @rep["good\nmorning"].should == "guten\r\nMorgen"
